about summary refs log tree commit diff
path: root/stdio-common/tst-printf.c
diff options
context:
space:
mode:
authorJoseph Myers <joseph@codesourcery.com>2017-01-11 14:02:23 +0000
committerJoseph Myers <joseph@codesourcery.com>2017-01-11 14:02:23 +0000
commit3c9378265a8633e2c85a393b54a16abcf64fe616 (patch)
tree0f6ff383099de1314f7134b24a8b05cae339a82e /stdio-common/tst-printf.c
parent436cfba0abf749e5993b52dce589bae482f8c58a (diff)
downloadglibc-3c9378265a8633e2c85a393b54a16abcf64fe616.tar.gz
glibc-3c9378265a8633e2c85a393b54a16abcf64fe616.tar.xz
glibc-3c9378265a8633e2c85a393b54a16abcf64fe616.zip
Fix testsuite build for GCC 7 -Wformat-truncation.
This patch fixes the glibc testsuite build for GCC 7
-Wformat-truncation, newly moved out of -Wformat-length and with some
further warnings that didn't previously appear.  Two tests that
previously disabled -Wformat-length are changed to disable
-Wformat-truncation instead; two others are made to disable that
option as well.

Tested (compilation only) with build-many-glibcs.py for aarch64 with
GCC mainline.

	* stdio-common/tst-printf.c [__GNUC_PREREQ (7, 0)]: Ignore
	-Wformat-truncation instead of -Wformat-length.
	* time/tst-strptime2.c (mkbuf) [__GNUC_PREREQ (7, 0)]: Likewise.
	* stdio-common/tstdiomisc.c (F): Ignore -Wformat-truncation for
	GCC 7.
	* wcsmbs/tst-wcstof.c: Include <libc-internal.h>.
	(do_test): Ignore -Wformat-truncation for GCC 7.
Diffstat (limited to 'stdio-common/tst-printf.c')
-rw-r--r--stdio-common/tst-printf.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/stdio-common/tst-printf.c b/stdio-common/tst-printf.c
index 74150c5e54..719b3eb08c 100644
--- a/stdio-common/tst-printf.c
+++ b/stdio-common/tst-printf.c
@@ -33,8 +33,9 @@
 DIAG_IGNORE_NEEDS_COMMENT (4.9, "-Wformat");
 
 #if __GNUC_PREREQ (7, 0)
-/* Compiler warnings about format lengths should also be ignored.  */
-DIAG_IGNORE_NEEDS_COMMENT (7.0, "-Wformat-length");
+/* Compiler warnings about snprintf output truncation should also be
+   ignored.  */
+DIAG_IGNORE_NEEDS_COMMENT (7.0, "-Wformat-truncation");
 #endif
 
 static void rfg1 (void);